@@ -267,7 +267,7 @@ public class PythonGateway {
      * @param processDefinitionName process definition name
      */
     private ProcessDefinition getProcessDefinition(User user, long projectCode, String processDefinitionName) {
-        Map<String, Object> verifyProcessDefinitionExists = processDefinitionService.verifyProcessDefinitionName(user, projectCode, processDefinitionName);
+        Map<String, Object> verifyProcessDefinitionExists = processDefinitionService.verifyProcessDefinitionName(user, projectCode, processDefinitionName, 0);
         Status verifyStatus = (Status) verifyProcessDefinitionExists.get(Constants.STATUS);
 
         ProcessDefinition processDefinition = null;
@@ -325,7 +325,7 @@ public class PythonGateway {
                                     String cronTime,
                                     String workerGroup,
                                     String warningType,
-                                    int warningGroupId,
+                                    Integer warningGroupId,
                                     Integer timeout
     ) {
         User user = usersService.queryUser(userName);
