@@ -153,7 +153,7 @@ public interface ProcessDefinitionService {
                                                    long targetProjectCode);
 
     /**
-     * update  process definition
+     * update process definition, with whole process definition object including task definition, task relation and location.
      *
      * @param loginUser login user
      * @param projectCode project code
@@ -187,11 +187,25 @@ public interface ProcessDefinitionService {
      * @param loginUser login user
      * @param projectCode project code
      * @param name name
+     * @param processDefinitionCode processDefinitionCode
      * @return true if process definition name not exists, otherwise false
      */
     Map<String, Object> verifyProcessDefinitionName(User loginUser,
                                                     long projectCode,
-                                                    String name);
+                                                    String name,
+                                                    long processDefinitionCode);
+
+    /**
+     * batch delete process definition by code
+     *
+     * @param loginUser login user
+     * @param projectCode project code
+     * @param codes process definition codes
+     * @return delete result code
+     */
+    Map<String, Object> batchDeleteProcessDefinitionByCodes(User loginUser,
+                                                           long projectCode,
+                                                           String codes);
 
     /**
      * delete process definition by code
@@ -391,7 +405,7 @@ public interface ProcessDefinitionService {
                                                      ProcessExecutionTypeEnum executionType);
 
     /**
-     * update process definition basic info
+     * update process definition basic info, not including task definition, task relation and location.
      *
      * @param loginUser login user
      * @param projectCode project code
