@@ -165,7 +165,7 @@ public class ProcessDefinition {
      * warningGroupId
      */
     @TableField(exist = false)
-    private int warningGroupId;
+    private Integer warningGroupId;
 
     /**
      * execution type
@@ -393,11 +393,11 @@ public class ProcessDefinition {
         this.projectCode = projectCode;
     }
 
-    public int getWarningGroupId() {
+    public Integer getWarningGroupId() {
         return warningGroupId;
     }
 
-    public void setWarningGroupId(int warningGroupId) {
+    public void setWarningGroupId(Integer warningGroupId) {
         this.warningGroupId = warningGroupId;
     }
 
