@@ -17,31 +17,25 @@
 
 package org.apache.dolphinscheduler.dao.mapper;
 
-import org.apache.dolphinscheduler.common.enums.AlertStatus;
 import org.apache.dolphinscheduler.dao.entity.Alert;
 
+import org.apache.ibatis.annotations.Mapper;
 import org.apache.ibatis.annotations.Param;
 
-import java.util.List;
+import java.util.Date;
 
 import com.baomidou.mybatisplus.core.mapper.BaseMapper;
 
 /**
  * alert mapper interface
  */
+@Mapper
 public interface AlertMapper extends BaseMapper<Alert> {
 
-    /**
-     * list alert by status
-     * @param alertStatus alertStatus
-     * @return alert list
-     */
-    List<Alert> listAlertByStatus(@Param("alertStatus") AlertStatus alertStatus);
-
     /**
      * Insert server crash alert
      * <p>This method will ensure that there is at most one unsent alert which has the same content in the database.
      */
-    void insertAlertWhenServerCrash(@Param("alert") Alert alert);
+    void insertAlertWhenServerCrash(@Param("alert") Alert alert, @Param("crashAlarmSuppressionStartTime") Date crashAlarmSuppressionStartTime);
 
 }
