@@ -19,6 +19,7 @@ package org.apache.dolphinscheduler.dao.mapper;
 
 import org.apache.dolphinscheduler.dao.entity.DependentProcessDefinition;
 import org.apache.dolphinscheduler.dao.entity.ProcessLineage;
+import org.apache.dolphinscheduler.dao.entity.TaskMainInfo;
 import org.apache.dolphinscheduler.dao.entity.WorkFlowLineage;
 
 import org.apache.ibatis.annotations.Param;
@@ -103,4 +104,44 @@ public interface WorkFlowLineageMapper {
     List<DependentProcessDefinition> queryUpstreamDependentParamsByProcessDefinitionCode(@Param("code") long code,
                                                                                          @Param("taskType") String taskType);
 
+    /**
+     * Query all tasks type sub process depend on process definition.
+     *
+     * Query all upstream tasks from task type sub process.
+     *
+     * @param projectCode Project code want to query tasks dependence
+     * @param processDefinitionCode Process definition code want to query tasks dependence
+     * @return List of TaskMainInfo
+     */
+    List<TaskMainInfo> queryTaskSubProcessDepOnProcess(@Param("projectCode") long projectCode,
+                                                       @Param("processDefinitionCode") long processDefinitionCode);
+
+    /**
+     * Query all tasks type dependent depend on process definition.
+     *
+     * Query all downstream tasks from task type dependent, method `queryTaskDepOnTask` is a proper subset of
+     * current method `queryTaskDepOnProcess`. Which mean with the same parameter processDefinitionCode, all tasks in
+     * `queryTaskDepOnTask` are in the result of method `queryTaskDepOnProcess`.
+     *
+     * @param projectCode Project code want to query tasks dependence
+     * @param processDefinitionCode Process definition code want to query tasks dependence
+     * @return List of TaskMainInfo
+     */
+    List<TaskMainInfo> queryTaskDependentDepOnProcess(@Param("projectCode") long projectCode,
+                                                      @Param("processDefinitionCode") long processDefinitionCode);
+
+    /**
+     * Query all tasks depend on task, only downstream task support currently(from dependent task type).
+     *
+     * In case of dependent task type, method `queryTaskDepOnTask` is a proper subset of `queryTaskDepOnProcess`. Which
+     * mean with the same processDefinitionCode, all tasks in `queryTaskDepOnTask` are in method `queryTaskDepOnProcess`.
+     *
+     * @param projectCode Project code want to query tasks dependence
+     * @param processDefinitionCode Process definition code want to query tasks dependence
+     * @param taskCode Task code want to query tasks dependence
+     * @return dependent process definition
+     */
+    List<TaskMainInfo> queryTaskDepOnTask(@Param("projectCode") long projectCode,
+                                          @Param("processDefinitionCode") long processDefinitionCode,
+                                          @Param("taskCode") long taskCode);
 }
