@@ -17,19 +17,21 @@
 
 package org.apache.dolphinscheduler.dao.utils;
 
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_CONDITIONS;
+
 import org.apache.dolphinscheduler.common.Constants;
-import org.apache.dolphinscheduler.common.enums.ExecutionStatus;
 import org.apache.dolphinscheduler.common.enums.TaskDependType;
-import org.apache.dolphinscheduler.common.enums.TaskType;
 import org.apache.dolphinscheduler.common.graph.DAG;
 import org.apache.dolphinscheduler.common.model.TaskNode;
 import org.apache.dolphinscheduler.common.model.TaskNodeRelation;
 import org.apache.dolphinscheduler.common.process.ProcessDag;
-import org.apache.dolphinscheduler.common.task.switchtask.SwitchParameters;
-import org.apache.dolphinscheduler.common.task.switchtask.SwitchResultVo;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.dao.entity.ProcessData;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
+import org.apache.dolphinscheduler.plugin.task.api.TaskConstants;
+import org.apache.dolphinscheduler.plugin.task.api.enums.ExecutionStatus;
+import org.apache.dolphinscheduler.plugin.task.api.model.SwitchResultVo;
+import org.apache.dolphinscheduler.plugin.task.api.parameters.SwitchParameters;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -47,6 +49,57 @@ import com.fasterxml.jackson.core.JsonProcessingException;
  * dag helper test
  */
 public class DagHelperTest {
+
+    @Test
+    public void testHaveSubAfterNode(){
+        String parentNodeCode = "5293789969856";
+        List<TaskNodeRelation> taskNodeRelations = new ArrayList<>();
+        TaskNodeRelation relation = new TaskNodeRelation();
+        relation.setStartNode("5293789969856");
+        relation.setEndNode("5293789969857");
+        taskNodeRelations.add(relation);
+
+        TaskNodeRelation relationNext = new TaskNodeRelation();
+        relationNext.setStartNode("5293789969856");
+        relationNext.setEndNode("5293789969858");
+        taskNodeRelations.add(relationNext);
+
+        List<TaskNode> taskNodes = new ArrayList<>();
+        TaskNode node = new TaskNode();
+        node.setCode(5293789969856L);
+        node.setType("SHELL");
+
+        TaskNode subNode = new TaskNode();
+        subNode.setCode(5293789969857L);
+        subNode.setType("BLOCKING");
+        subNode.setPreTasks("[5293789969856]");
+
+        TaskNode subNextNode = new TaskNode();
+        subNextNode.setCode(5293789969858L);
+        subNextNode.setType("CONDITIONS");
+        subNextNode.setPreTasks("[5293789969856]");
+
+        taskNodes.add(node);
+        taskNodes.add(subNode);
+        taskNodes.add(subNextNode);
+
+        ProcessDag processDag = new ProcessDag();
+        processDag.setEdges(taskNodeRelations);
+        processDag.setNodes(taskNodes);
+        DAG<String,TaskNode,TaskNodeRelation> dag = DagHelper.buildDagGraph(processDag);
+        boolean canSubmit = DagHelper.haveAllNodeAfterNode(parentNodeCode, dag);
+        Assert.assertTrue(canSubmit);
+
+        boolean haveBlocking = DagHelper.haveBlockingAfterNode(parentNodeCode, dag);
+        Assert.assertTrue(haveBlocking);
+
+        boolean haveConditions = DagHelper.haveConditionsAfterNode(parentNodeCode, dag);
+        Assert.assertTrue(haveConditions);
+
+        boolean dependent = DagHelper.haveSubAfterNode(parentNodeCode, dag, TaskConstants.TASK_TYPE_DEPENDENT);
+        Assert.assertFalse(dependent);
+    }
+
     /**
      * test task node can submit
      *
@@ -208,7 +261,7 @@ public class DagHelperTest {
         completeTaskList.put("2", new TaskInstance());
         completeTaskList.put("4", new TaskInstance());
         TaskNode node3 = dag.getNode("3");
-        node3.setType(TaskType.CONDITIONS.getDesc());
+        node3.setType(TASK_TYPE_CONDITIONS);
         node3.setConditionResult("{\n"
                 +
                 "                \"successNode\": [5\n"
@@ -279,9 +332,16 @@ public class DagHelperTest {
     }
 
     /**
+     * process:
      * 1->2->3->5->7
      * 4->3->6
-     * 2->8->5->7
+     * 1->2->8->5->7
+     * DAG graph:
+     *      4 ->   -> 6
+     *          \ /
+     * 1 -> 2 -> 3 -> 5 -> 7
+     *       \       /
+     *        -> 8 ->
      *
      * @return dag
      * @throws JsonProcessingException if error throws JsonProcessingException
@@ -292,14 +352,14 @@ public class DagHelperTest {
         node1.setId("1");
         node1.setName("1");
         node1.setCode(1);
-        node1.setType(TaskType.SHELL.getDesc());
+        node1.setType("SHELL");
         taskNodeList.add(node1);
 
         TaskNode node2 = new TaskNode();
         node2.setId("2");
         node2.setName("2");
         node2.setCode(2);
-        node2.setType(TaskType.SHELL.getDesc());
+        node2.setType("SHELL");
         List<String> dep2 = new ArrayList<>();
         dep2.add("1");
         node2.setPreTasks(JSONUtils.toJsonString(dep2));
@@ -309,14 +369,14 @@ public class DagHelperTest {
         node4.setId("4");
         node4.setName("4");
         node4.setCode(4);
-        node4.setType(TaskType.SHELL.getDesc());
+        node4.setType("SHELL");
         taskNodeList.add(node4);
 
         TaskNode node3 = new TaskNode();
         node3.setId("3");
         node3.setName("3");
         node3.setCode(3);
-        node3.setType(TaskType.SHELL.getDesc());
+        node3.setType("SHELL");
         List<String> dep3 = new ArrayList<>();
         dep3.add("2");
         dep3.add("4");
@@ -327,7 +387,7 @@ public class DagHelperTest {
         node5.setId("5");
         node5.setName("5");
         node5.setCode(5);
-        node5.setType(TaskType.SHELL.getDesc());
+        node5.setType("SHELL");
         List<String> dep5 = new ArrayList<>();
         dep5.add("3");
         dep5.add("8");
@@ -338,7 +398,7 @@ public class DagHelperTest {
         node6.setId("6");
         node6.setName("6");
         node6.setCode(6);
-        node6.setType(TaskType.SHELL.getDesc());
+        node6.setType("SHELL");
         List<String> dep6 = new ArrayList<>();
         dep6.add("3");
         node6.setPreTasks(JSONUtils.toJsonString(dep6));
@@ -348,7 +408,7 @@ public class DagHelperTest {
         node7.setId("7");
         node7.setName("7");
         node7.setCode(7);
-        node7.setType(TaskType.SHELL.getDesc());
+        node7.setType("SHELL");
         List<String> dep7 = new ArrayList<>();
         dep7.add("5");
         node7.setPreTasks(JSONUtils.toJsonString(dep7));
@@ -358,7 +418,7 @@ public class DagHelperTest {
         node8.setId("8");
         node8.setName("8");
         node8.setCode(8);
-        node8.setType(TaskType.SHELL.getDesc());
+        node8.setType("SHELL");
         List<String> dep8 = new ArrayList<>();
         dep8.add("2");
         node8.setPreTasks(JSONUtils.toJsonString(dep8));
@@ -376,9 +436,12 @@ public class DagHelperTest {
     }
 
     /**
-     * 1->2->3->5->7
-     * 4->3->6
-     * 2->8->5->7
+     * DAG graph:
+     *    2
+     *    ↑
+     * 0->1(switch)
+     *    ↓
+     *    4
      *
      * @return dag
      * @throws JsonProcessingException if error throws JsonProcessingException
@@ -446,15 +509,15 @@ public class DagHelperTest {
         SwitchParameters conditionsParameters = new SwitchParameters();
         SwitchResultVo switchResultVo1 = new SwitchResultVo();
         switchResultVo1.setCondition(" 2 == 1");
-        switchResultVo1.setNextNode(2L);
+        switchResultVo1.setNextNode("2");
         SwitchResultVo switchResultVo2 = new SwitchResultVo();
         switchResultVo2.setCondition(" 2 == 2");
-        switchResultVo2.setNextNode(4L);
+        switchResultVo2.setNextNode("4");
         List<SwitchResultVo> list = new ArrayList<>();
         list.add(switchResultVo1);
         list.add(switchResultVo2);
         conditionsParameters.setDependTaskList(list);
-        conditionsParameters.setNextNode(5L);
+        conditionsParameters.setNextNode("5");
         conditionsParameters.setRelation("AND");
 
         // in: AND(AND(1 is SUCCESS))
