@@ -16,3 +16,7 @@
 # under the License.
 
 """Init root of pydolphinscheduler."""
+
+from pkg_resources import get_distribution
+
+__version__ = get_distribution("apache-dolphinscheduler").version
