@@ -17,8 +17,8 @@
 
 package org.apache.dolphinscheduler.remote.command;
 
-import org.apache.dolphinscheduler.common.enums.ExecutionStatus;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
+import org.apache.dolphinscheduler.plugin.task.api.enums.ExecutionStatus;
 
 import java.io.Serializable;
 
@@ -46,7 +46,8 @@ public class StateEventChangeCommand implements Serializable {
     public StateEventChangeCommand(int sourceProcessInstanceId, int sourceTaskInstanceId,
                                    ExecutionStatus sourceStatus,
                                    int destProcessInstanceId,
-                                   int destTaskInstanceId) {
+                                   int destTaskInstanceId
+    ) {
         this.key = String.format("%d-%d-%d-%d",
                 sourceProcessInstanceId,
                 sourceTaskInstanceId,
