@@ -18,45 +18,32 @@
 package org.apache.dolphinscheduler.service.queue;
 
 import org.apache.dolphinscheduler.service.exceptions.TaskPriorityQueueException;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-import org.springframework.stereotype.Service;
 
 import java.util.concurrent.PriorityBlockingQueue;
 import java.util.concurrent.TimeUnit;
 
+import org.springframework.stereotype.Service;
+
 /**
  * A singleton of a task queue implemented using PriorityBlockingQueue
  */
 @Service
 public class TaskPriorityQueueImpl implements TaskPriorityQueue<TaskPriority> {
 
-    private static final Logger logger = LoggerFactory.getLogger(TaskPriorityQueueImpl.class);
-
     /**
-     * queue size
+     * Task queue, this queue is unbounded, this means it will cause OutOfMemoryError.
+     * The master will stop to generate the task if memory is too high.
      */
-    private static final Integer QUEUE_MAX_SIZE = 10000;
-
-    /**
-     * queue
-     */
-    private PriorityBlockingQueue<TaskPriority> queue = new PriorityBlockingQueue<>(QUEUE_MAX_SIZE);
+    private final PriorityBlockingQueue<TaskPriority> queue = new PriorityBlockingQueue<>(3000);
 
     /**
      * put task takePriorityInfo
      *
      * @param taskPriorityInfo takePriorityInfo
-     * @throws TaskPriorityQueueException
      */
     @Override
-    public void put(TaskPriority taskPriorityInfo) throws TaskPriorityQueueException {
-        if (!queue.contains(taskPriorityInfo)) {
-            queue.put(taskPriorityInfo);
-        } else {
-            logger.warn("the priorityBlockingQueue contain the task already, taskId: {}, processInstanceId: {}",
-                    taskPriorityInfo.getTaskId(), taskPriorityInfo.getProcessInstanceId());
-        }
+    public void put(TaskPriority taskPriorityInfo) {
+        queue.put(taskPriorityInfo);
     }
 
     /**
