@@ -15,9 +15,9 @@ package org.apache.dolphinscheduler.plugin.task.python;/*
  * limitations under the License.
  */
 
+import org.apache.dolphinscheduler.plugin.task.api.TaskChannel;
+import org.apache.dolphinscheduler.plugin.task.api.TaskChannelFactory;
 import org.apache.dolphinscheduler.spi.params.base.PluginParams;
-import org.apache.dolphinscheduler.spi.task.TaskChannel;
-import org.apache.dolphinscheduler.spi.task.TaskChannelFactory;
 
 import java.util.List;
 
